@@ -43,7 +43,7 @@ struct gnutls_error_entry
 };
 typedef struct gnutls_error_entry gnutls_error_entry;
 
-static gnutls_error_entry error_algorithms[] = {
+static const gnutls_error_entry error_algorithms[] = {
   /* "Short Description", Error code define, critical (0,1) -- 1 in most cases */
   ERROR_ENTRY ("Success.", GNUTLS_E_SUCCESS, 0),
   ERROR_ENTRY ("Could not negotiate a supported cipher suite.",
@@ -234,18 +234,18 @@ static gnutls_error_entry error_algorithms[] = {
   ERROR_ENTRY ("Failed to acquire random data.", GNUTLS_E_RANDOM_FAILED,
 	       1),
 
-  ERROR_ENTRY("Received a TLS/IA Intermediate Phase Finished message",
-	      GNUTLS_E_WARNING_IA_IPHF_RECEIVED, 0),
-  ERROR_ENTRY("Received a TLS/IA Final Phase Finished message",
-	      GNUTLS_E_WARNING_IA_FPHF_RECEIVED, 0),
-  ERROR_ENTRY("Verifying TLS/IA phase checksum failed",
-	      GNUTLS_E_IA_VERIFY_FAILED, 1),
+  ERROR_ENTRY ("Received a TLS/IA Intermediate Phase Finished message",
+	       GNUTLS_E_WARNING_IA_IPHF_RECEIVED, 0),
+  ERROR_ENTRY ("Received a TLS/IA Final Phase Finished message",
+	       GNUTLS_E_WARNING_IA_FPHF_RECEIVED, 0),
+  ERROR_ENTRY ("Verifying TLS/IA phase checksum failed",
+	       GNUTLS_E_IA_VERIFY_FAILED, 1),
 
   {NULL, NULL, 0, 0}
 };
 
 #define GNUTLS_ERROR_LOOP(b) \
-        gnutls_error_entry *p; \
+        const gnutls_error_entry *p; \
                 for(p = error_algorithms; p->desc != NULL; p++) { b ; }
 
 #define GNUTLS_ERROR_ALG_LOOP(a) \
