@@ -442,7 +442,7 @@ cleanup:
   **/
 int
 gnutls_x509_crq_get_challenge_password (gnutls_x509_crq_t crq,
-					const char *pass,
+					char *pass,
 					size_t * sizeof_pass)
 {
   if (crq == NULL)
